@@ -1,5 +1,5 @@
 #
-# $Id: Driver.pm,v 0.1 1999/12/07 21:09:44 ram Exp $
+# $Id: Driver.pm,v 0.1.1.1 2000/03/05 22:21:58 ram Exp $
 #
 #  Copyright (c) 1999, Raphael Manfredi
 #  
@@ -8,6 +8,9 @@
 #
 # HISTORY
 # $Log: Driver.pm,v $
+# Revision 0.1.1.1  2000/03/05 22:21:58  ram
+# patch3: added end marker before pod
+#
 # Revision 0.1  1999/12/07 21:09:44  ram
 # Baseline for first alpha release.
 #
@@ -303,6 +306,7 @@ sub stamping_fn {
 }
 
 1;	# for require
+__END__
 
 =head1 NAME
 
