@@ -1,5 +1,5 @@
 #
-# $Id: Syslog.pm,v 0.1 1999/12/07 21:09:44 ram Exp $
+# $Id: Syslog.pm,v 0.1.1.1 2000/03/05 22:23:32 ram Exp $
 #
 #  Copyright (c) 1999, Raphael Manfredi
 #  
@@ -8,6 +8,9 @@
 #
 # HISTORY
 # $Log: Syslog.pm,v $
+# Revision 0.1.1.1  2000/03/05 22:23:32  ram
+# patch3: added end marker before pod
+#
 # Revision 0.1  1999/12/07 21:09:44  ram
 # Baseline for first alpha release.
 #
@@ -148,6 +151,7 @@ sub emit {
 }
 
 1;	# for require
+__END__
 
 =head1 NAME
 
